@@ -1,5 +1,6 @@
 #!/usr/pkg/bin/python2.7
 from __future__ import print_function
+
 from macholib._cmdline import main as _main
 
 
@@ -9,12 +10,12 @@ def print_file(fp, path):
 
 def main():
     print(
-        "WARNING: 'macho_find' is deprecated, "
-        "use 'python -mmacholib dump' instead")
+        "WARNING: 'macho_find' is deprecated, " "use 'python -mmacholib dump' instead"
+    )
     _main(print_file)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     try:
         main()
     except KeyboardInterrupt:
